==> zio-aws-ec2_2.12-5.17.145.1-sources.jar: zio/aws/ec2/model/TrafficMirrorPortRangeRequest.scala <==
package zio.aws.ec2.model
import zio.aws.ec2.model.primitives.Integer
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class TrafficMirrorPortRangeRequest(
    fromPort: Option[Integer] = None,
    toPort: Option[Integer] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.TrafficMirrorPortRangeRequest = {
    import TrafficMirrorPortRangeRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.TrafficMirrorPortRangeRequest
      .builder()
      .optionallyWith(fromPort.map(value => value: java.lang.Integer))(
        _.fromPort
      )
      .optionallyWith(toPort.map(value => value: java.lang.Integer))(_.toPort)
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.TrafficMirrorPortRangeRequest.ReadOnly =
    zio.aws.ec2.model.TrafficMirrorPortRangeRequest.wrap(buildAwsValue())
}
object TrafficMirrorPortRangeRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.TrafficMirrorPortRangeRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.TrafficMirrorPortRangeRequest =
      zio.aws.ec2.model.TrafficMirrorPortRangeRequest(
        fromPort.map(value => value),
        toPort.map(value => value)
      )
    def fromPort: Option[Integer]
    def toPort: Option[Integer]
    def getFromPort: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("fromPort", fromPort)
    def getToPort: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("toPort", toPort)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.TrafficMirrorPortRangeRequest
  ) extends zio.aws.ec2.model.TrafficMirrorPortRangeRequest.ReadOnly {
    override val fromPort: Option[Integer] =
      scala.Option(impl.fromPort()).map(value => value: Integer)
    override val toPort: Option[Integer] =
      scala.Option(impl.toPort()).map(value => value: Integer)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.TrafficMirrorPortRangeRequest
  ): zio.aws.ec2.model.TrafficMirrorPortRangeRequest.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-ec2_2.12-5.19.12.1-sources.jar: zio/aws/ec2/model/TrafficMirrorPortRangeRequest.scala <==
package zio.aws.ec2.model
import zio.aws.ec2.model.primitives.Integer
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class TrafficMirrorPortRangeRequest(
    fromPort: Optional[Integer] = Optional.Absent,
    toPort: Optional[Integer] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.TrafficMirrorPortRangeRequest = {
    import TrafficMirrorPortRangeRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.TrafficMirrorPortRangeRequest
      .builder()
      .optionallyWith(fromPort.map(value => value: java.lang.Integer))(
        _.fromPort
      )
      .optionallyWith(toPort.map(value => value: java.lang.Integer))(_.toPort)
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.TrafficMirrorPortRangeRequest.ReadOnly =
    zio.aws.ec2.model.TrafficMirrorPortRangeRequest.wrap(buildAwsValue())
}
object TrafficMirrorPortRangeRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.TrafficMirrorPortRangeRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.TrafficMirrorPortRangeRequest =
      zio.aws.ec2.model.TrafficMirrorPortRangeRequest(
        fromPort.map(value => value),
        toPort.map(value => value)
      )
    def fromPort: Optional[Integer]
    def toPort: Optional[Integer]
    def getFromPort: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("fromPort", fromPort)
    def getToPort: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("toPort", toPort)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.TrafficMirrorPortRangeRequest
  ) extends zio.aws.ec2.model.TrafficMirrorPortRangeRequest.ReadOnly {
    override val fromPort: Optional[Integer] = zio.aws.core.internal
      .optionalFromNullable(impl.fromPort())
      .map(value => value: Integer)
    override val toPort: Optional[Integer] = zio.aws.core.internal
      .optionalFromNullable(impl.toPort())
      .map(value => value: Integer)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.TrafficMirrorPortRangeRequest
  ): zio.aws.ec2.model.TrafficMirrorPortRangeRequest.ReadOnly = new Wrapper(
    impl
  )
}
